@@ -16,6 +16,7 @@ class Act():
             print 'Act %s does not exist in venue %s' % (self.venue.VENUE_NAME, self.actname)
             raise
         self.get_settings()
+        self.uwsgi_linker()
 
     def get_settings(self):
         syspath = sys.path
@@ -24,18 +25,24 @@ class Act():
         sys.path = syspath
         self.settings = settings
 
-    def uwsgi_linker(self, linkmode='link'):
-        linkmodes = ['link', 'unlink', 'relink']
-        inifile = os.path.abspath(os.path.join(self.acthome, 'uwsgi.ini'))
-        linkfile = self.settings.UWSGI_VASSALS
+    def uwsgi_linker(self, linkmode=None):
+        """Links the uwsgi.ini file to the uwsgi emperor's vassals directory
+        (set in backstage.backstage_settings UWSGI_VASSALS)
+        """
+        linkmodes = [None, 'link', 'unlink', 'relink']
+        vassal_name = 'backstage-%s-acts-%s.ini' % (self.venue.VENUE_NAME, self.actname)
+        self.vassal_file = os.path.join(self.settings.UWSGI_VASSALS, vassal_name)
         if linkmode not in linkmodes:
             return 'Usage: uwsgi_linker <%s>' % (linkmodes)
-        if linkmode == 'link':
+        if linkmode == None:
             pass
+        elif linkmode == 'link':
+            os.symlink(self.uwsgifile, self.vassal_file)
         elif linkmode == 'unlink':
-            pass
+            os.unlink(self.vassal_file)
         elif linkmode == 'relink':
-            pass
+            os.unlink(self.vassal_file)
+            os.symlink(self.uwsgifile, self.vassal_file)
 
 def new_act(venue, actname):
     """create a new Act within a backstage Venue"""
